@@ -1,6 +1,5 @@
-/*  $Id: cvtbatch.c,v 1.21 2003/01/19 01:15:26 rra Exp $
-**
-**  Read file list on standard input and spew out batchfiles.
+/*  $Id: cvtbatch.c 9623 2014-03-15 22:29:46Z iulius $
+**  Read file list on standard input and spew out batch files.
 */
 
 #include "config.h"
@@ -10,9 +9,9 @@
 #include "inn/messages.h"
 #include "inn/qio.h"
 #include "inn/wire.h"
-#include "libinn.h"
-#include "paths.h"
-#include "storage.h"
+#include "inn/libinn.h"
+#include "inn/paths.h"
+#include "inn/storage.h"
 
 
 int
@@ -27,7 +26,8 @@ main(int ac, char *av[]) {
     bool	Dirty;
     TOKEN	token;
     ARTHANDLE	*art;
-    int		len;
+    size_t	len;
+    time_t      arrived;
 
     /* First thing, set up our identity. */
     message_program_name = "cvtbatch";
@@ -42,9 +42,11 @@ main(int ac, char *av[]) {
             die("usage error");
             break;
 	case 'w':
+            free(format);
 	    for (p = format = optarg; *p; p++) {
 		switch (*p) {
 		case FEED_BYTESIZE:
+                case FEED_TIMERECEIVED:
 		case FEED_FULLNAME:
 		case FEED_MESSAGEID:
 		case FEED_NAME:
@@ -54,7 +56,6 @@ main(int ac, char *av[]) {
 	    }
 	}
     ac -= optind;
-    av += optind;
     if (ac)
 	die("usage error");
 
@@ -73,14 +74,16 @@ main(int ac, char *av[]) {
 	if (!IsToken(line))
 	    continue;
 	token = TextToToken(line);
-	if ((art = SMretrieve(token, RETR_HEAD)) == NULL)
+	if ((art = SMretrieve(token, RETR_ALL)) == NULL)
 	    continue;
-        text = wire_findheader(art->data, art->len, "Message-ID");
+        text = wire_findheader(art->data, art->len, "Message-ID", true);
 	if (text == NULL) {
 	    SMfreearticle(art);
 	    continue;
 	}
 	len = art->len;
+        arrived = art->arrived;
+
 	for (r = text; r < art->data + art->len; r++) {
 	    if (*r == '\r' || *r == '\n')
 		break;
@@ -102,7 +105,7 @@ main(int ac, char *av[]) {
 	    case FEED_BYTESIZE:
 		if (Dirty)
 		    putchar(' ');
-		printf("%d", len);
+		printf("%lu", (unsigned long)len);
 		break;
 	    case FEED_FULLNAME:
 	    case FEED_NAME:
@@ -115,6 +118,11 @@ main(int ac, char *av[]) {
 		    putchar(' ');
 		printf("%s", q);
 		break;
+            case FEED_TIMERECEIVED:
+                if (Dirty)
+                    putchar(' ');
+                printf("%lu", (unsigned long) arrived);
+                break;
 	    }
 	    Dirty = true;
 	}
