@@ -1,4 +1,4 @@
-/*  $Id: innlistener.c 8469 2009-05-16 12:43:53Z iulius $
+/*  $Id: innlistener.c 9233 2011-07-09 19:17:21Z iulius $
 **
 **  The implementation of the innfeed InnListener class.
 **
@@ -16,8 +16,9 @@
 #include <syslog.h>
 #include <time.h>
 
-#include "inn/messages.h"
 #include "inn/libinn.h"
+#include "inn/messages.h"
+#include "inn/nntp.h"
 
 #include "article.h"
 #include "buffer.h"
@@ -25,7 +26,6 @@
 #include "endpoint.h"
 #include "host.h"
 #include "innlistener.h"
-#include "nntp.h"
 #include "tape.h"
 
 #define LISTENER_INPUT_BUFFER (1024 * 8) /* byte size of the input buffer */
@@ -54,7 +54,7 @@ static FILE *droppedFp = NULL ;
 static long droppedCount = 0 ;
 static int droppedFileCount = 0 ;
 static char *dropArtFile = NULL ;
-static bool fastExit = false ;
+bool fastExit = false ;
 
 extern const char *pidFile ;
 extern const char *InputFile ;
@@ -526,7 +526,7 @@ static void newArticleCommand (EndPoint ep, IoStatus i,
               
               /* See if this is a valid peername */
               for(s = peer; *s; s++)
-                if (!CTYPE(isalnum, *s) && *s != '.' && *s != '-' && *s != '_')
+                if (!isalnum((unsigned char) *s) && *s != '.' && *s != '-' && *s != '_')
                   break;
               if (*s != 0) {
                   warn ("ME invalid peername %s", peer) ;
