@@ -1,4 +1,4 @@
-/*  $Id: hashtab.c 9768 2014-12-07 21:22:57Z iulius $
+/*  $Id: hashtab.c 9907 2015-06-25 19:44:59Z iulius $
 **
 **  Generic hash table implementation.
 **
@@ -57,6 +57,9 @@ hash_size(size_t target)
     int n;
     size_t size;
 
+    if (target == 0) {
+        return 4;
+    }
     size = target - 1;
     for (n = 0; size > 0; n++)
         size >>= 1;
