@@ -1,4 +1,4 @@
-/*  $Id: buffindexed.c 9024 2010-03-21 16:49:30Z iulius $
+/*  $Id: buffindexed.c 9902 2015-06-20 14:10:08Z iulius $
 **
 **  Overview buffer and index method.
 */
@@ -7,7 +7,7 @@
 ** Buffindexed using shared memory on ovbuff by Sang-yong Suh
 **
 ** During the recent discussions in inn-workers, Alex Kiernan found
-** that INN LockRange() is not working for MMAPed file.  This explains
+** that inn_lock_range() is not working for MMAPed file.  This explains
 ** why buffindexed has long outstanding bugs such as "could not MMAP...".
 **
 ** This version corrects the file locking error by using shared memory.
@@ -36,6 +36,7 @@
 #include "inn/paths.h"
 #include "ovinterface.h"
 #include "inn/storage.h"
+#include "inn/fdflag.h"
 
 /* Yes. I know that it violates INN coding style. However, this allows
  * me to compile this new version without reconfiguring INN.
@@ -610,7 +611,7 @@ static bool ovbuffinit_disks(void) {
 	syswarn("buffindexed: ERROR opening '%s'", ovbuff->path);
 	return false;
       } else {
-	close_on_exec(fd, true);
+	fdflag_close_exec(fd, true);
 	ovbuff->fd = fd;
       }
     }
@@ -1047,7 +1048,7 @@ bool buffindexed_open(int mode) {
       close(GROUPfd);
       return false;
     }
-    GROUPentries = (GROUPENTRY *)((char *)GROUPheader + sizeof(GROUPHEADER));
+    GROUPentries = (void *) &GROUPheader[1];
   } else {
     GROUPcount = 0;
     if (!GROUPexpand(mode)) {
@@ -1056,7 +1057,7 @@ bool buffindexed_open(int mode) {
       return false;
     }
   }
-  close_on_exec(GROUPfd, true);
+  fdflag_close_exec(GROUPfd, true);
 
   free(groupfn);
   Cutofflow = false;
@@ -1202,7 +1203,7 @@ static bool GROUPremapifneeded(GROUPLOC loc) {
     syswarn("buffindexed: Could not mmap group.index in GROUPremapifneeded");
     return false;
   }
-  GROUPentries = (GROUPENTRY *)((char *)GROUPheader + sizeof(GROUPHEADER));
+  GROUPentries = (void *) &GROUPheader[1];
   return true;
 }
 
@@ -1237,7 +1238,7 @@ static bool GROUPexpand(int mode) {
     syswarn("buffindexed: Could not mmap group.index in GROUPexpand");
     return false;
   }
-  GROUPentries = (GROUPENTRY *)((char *)GROUPheader + sizeof(GROUPHEADER));
+  GROUPentries = (void *) &GROUPheader[1];
   if (GROUPheader->magic != GROUPHEADERMAGIC) {
     GROUPheader->magic = GROUPHEADERMAGIC;
     GROUPLOCclear(&GROUPheader->freelist);
@@ -1663,7 +1664,7 @@ ovgroupmmap(GROUPENTRY *ge, ARTNUM low, ARTNUM high, bool needov)
       ovgroupunmap();
       return false;
     }
-    ovblock = (OVBLOCK *)((char *)addr + pagefudge);
+    ovblock = (void *)((char *)addr + pagefudge);
     if (ov.index == ge->curindex.index && ov.blocknum == ge->curindex.blocknum) {
       limit = ge->curindexoffset;
     } else {
@@ -2237,7 +2238,7 @@ bool buffindexed_ctl(OVCTLTYPE type, void *val) {
 
 void buffindexed_close(void) {
   struct stat	sb;
-  OVBUFF	*ovbuff = ovbufftab;
+  OVBUFF	*ovbuff = NULL;
 #ifdef OV_DEBUG
   FILE		*F = NULL;
   pid_t		pid;
@@ -2249,6 +2250,7 @@ void buffindexed_close(void) {
 #endif /* OV_DEBUG */
 
 #ifdef OV_DEBUG
+  ovbuff = ovbufftab;
   for (; ovbuff != (OVBUFF *)NULL; ovbuff = ovbuff->next) {
     for (i = 0 ; i < ovbuff->totalblk ; i++) {
       trace = &ovbuff->trace[i];
