@@ -73,7 +73,6 @@
 #include "config.h"
 #include "clibrary.h"
 #include "portable/socket.h"
-#include "portable/time.h"
 #include <errno.h>
 #include <fcntl.h>
 #ifdef HAVE_LIMITS_H
@@ -83,13 +82,22 @@
 #ifdef HAVE_SYS_SELECT_H
 # include <sys/select.h>
 #endif
+#ifndef HAVE_ZLIB_H
+# undef HAVE_ZLIB
+#endif
 #ifdef HAVE_ZLIB
 # include <zlib.h>
 # define MAX_UNZIP_SZ 100000
 # define COMPRESS_MIN 600
 #endif
 
+#ifdef HAVE_SYS_TIME_H
+# include <sys/time.h>
+#endif
+#include <time.h>
+
 #include "conffile.h"
+#include "inn/fdflag.h"
 #include "inn/innconf.h"
 #include "inn/libinn.h"
 #include "inn/messages.h"
@@ -97,16 +105,15 @@
 #include "inn/paths.h"
 #include "inn/storage.h"
 
+#ifdef HAVE_UNIX_DOMAIN_SOCKETS
+# include "portable/socket-unix.h"
+#endif
+
 #include "inn/ov.h"
 #include "ovinterface.h"
 #include "ovdb.h"
 #include "ovdb-private.h"
-
-#ifdef HAVE_UNIX_DOMAIN_SOCKETS
-# include <sys/un.h>
-#endif
-
-#ifndef USE_BERKELEY_DB
+#ifndef HAVE_BDB
 
 /* Provide stub functions if we don't have db */
 
@@ -150,7 +157,7 @@ bool ovdb_ctl(OVCTLTYPE type UNUSED, void *val UNUSED)
 
 void ovdb_close(void) { }
 
-#else /* USE_BERKELEY_DB */
+#else /* HAVE_BDB */
 
 #define EXPIREGROUP_TXN_SIZE 100
 #define DELETE_TXN_SIZE 500
@@ -272,19 +279,22 @@ static int client_connect(void)
 	return -1;
     }
 
+    memset(&sa, 0, sizeof sa);
 #ifdef HAVE_UNIX_DOMAIN_SOCKETS
     sa.sun_family = AF_UNIX;
     path = concatpath(innconf->pathrun, OVDB_SERVER_SOCKET);
     strlcpy(sa.sun_path, path, sizeof(sa.sun_path));
     free(path);
+    r = connect(clientfd, (struct sockaddr *) &sa, SUN_LEN(&sa));
 #else
     sa.sin_family = AF_INET;
     sa.sin_port = 0;
-    sa.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
+    sa.sin_addr.s_addr = htonl(0x7f000001UL);
     bind(clientfd, (struct sockaddr *) &sa, sizeof sa);
     sa.sin_port = htons(OVDB_SERVER_PORT);
+    r = connect(clientfd, (struct sockaddr *) &sa, sizeof sa);
 #endif
-    if((r = connect(clientfd, (struct sockaddr *) &sa, sizeof sa)) != 0) {
+    if(r != 0) {
         syswarn("OVDB: rc: cant connect to server");
 	close(clientfd);
 	clientfd = -1;
@@ -1262,7 +1272,7 @@ bool ovdb_getlock(int mode)
                      " running");
 	    return false;
 	}
-	close_on_exec(lockfd, true);
+	fdflag_close_exec(lockfd, true);
 	free(lockfn);
     } else
 	return true;
@@ -1719,7 +1729,7 @@ ovdb_groupadd(const char *group, ARTNUM lo, ARTNUM hi, char *flag)
 		&& !(gi.status & GROUPINFO_EXPIRING)
 		&& !(gi.status & GROUPINFO_MOVING)) {
 	int s, c = 0;
-	char g[MAXHEADERSIZE];
+	char g[MED_BUFFER];
 
 	strlcpy(g, group, sizeof(g));
 	s = strlen(g) + 1;
@@ -3053,4 +3063,4 @@ void ovdb_close(void)
     ovdb_releaselock();
 }
 
-#endif /* USE_BERKELEY_DB */
+#endif /* HAVE_BDB */
